@@ -10,7 +10,7 @@ config() {
   # Otherwise, we leave the .new copy for the admin to consider...
 }
 
-config etc/rc.d/rc.modules-2.6.30.5.new
+config etc/rc.d/rc.modules-2.6.33.5.new
 
 # If rc.modules is a real file, back it up:
 if [ -r etc/rc.d/rc.modules -a ! -L etc/rc.d/rc.modules ]; then
@@ -19,8 +19,12 @@ fi
 
 # A good idea whenever kernel modules are added or changed:
 if [ -x sbin/depmod ]; then
-  chroot . /sbin/depmod -a 2.6.30.5 1> /dev/null 2> /dev/null
+  chroot . /sbin/depmod -a 2.6.33.5 1> /dev/null 2> /dev/null
 fi
 
-( cd etc/rc.d ; rm -rf rc.modules-2.6.30.5-kirkwood )
-( cd etc/rc.d ; ln -sf rc.modules-2.6.30.5 rc.modules-2.6.30.5-kirkwood )
+( cd lib/modules/2.6.33.5-kirkwood ; rm -rf build )
+( cd lib/modules/2.6.33.5-kirkwood ; ln -sf ../../../usr/src/linux-2.6.33.5 build )
+( cd lib/modules/2.6.33.5-kirkwood ; rm -rf source )
+( cd lib/modules/2.6.33.5-kirkwood ; ln -sf ../../../usr/src/linux-2.6.33.5 source )
+( cd etc/rc.d ; rm -rf rc.modules-2.6.33.5-kirkwood )
+( cd etc/rc.d ; ln -sf rc.modules-2.6.33.5 rc.modules-2.6.33.5-kirkwood )
